@@ -1,14 +1,18 @@
 """Module containing top-level Typer app functionality."""
 
+import subprocess
 import typer
 import integrate_ai.sdk as sdk
 import integrate_ai.client as client
+from rich import print as rprint
 
 app = typer.Typer(no_args_is_help=True)
 
 app.add_typer(sdk.app, name="sdk")
 app.add_typer(client.app, name="client")
 
+package = "integrate-ai"
+
 
 @app.callback()
 def docs(
@@ -22,6 +26,16 @@ def docs(
     pass
 
 
+@app.command()
+def version():
+    """
+    The currently installed version of the cli.
+    """
+    show_version_command = f"pip show {package} | grep Version"
+    rprint(f"Getting current version for {package}.")
+    subprocess.run(show_version_command, check=True, shell=True)
+
+
 def main():
 
     app()
